* {
    box-sizing: border-box;
}

.nodisplay {
    display: none !important;
}

html, body {
    padding: 0;
    margin: 0;
    height: 100%;
}

main {
    min-height: 100%;
    padding: 2rem;
    --main-color: rgb(100, 100, 100);
    color: var(--main-color);
    font-size: 2rem;

    display: flex;
    flex-flow: row nowrap;
    align-items: flex-start;
    gap: 2rem;
}

.main-area {
    width: 0;
}

#drop-area {
    flex: 1 1 0;
    height: calc(100vh - 4rem);
    padding: 2rem;
    border: 4px dashed var(--main-color);
    position: -webkit-sticky;
    position: sticky;
    top: 2rem;

    display: flex;
    align-items: center;
    justify-content: center;
    text-align: center;
    user-select: none;
}

#drop-area.drag-active {
    --main-color: rgb(0, 130, 0);
    border: 4px solid var(--main-color);
    color: var(--main-color)
}

#drop-area.drag-active * {
    pointer-events: none;
}

#files-area {
    flex: 1 1 0;
    font-size: 1rem;
    color: black;
    padding: 0;

    display: flex;
    flex-direction: column;
    align-items: stretch;
    justify-content: start;
}

.file-container {
    border: 1px solid var(--main-color);
    background-color: rgb(250, 250, 250);
    margin: 0.2em;
    padding: 0.4em;
    text-align: left;
    display: flex;
    justify-content: space-between;
    align-items: center;
}

.file-name {
    min-width: 0;
    overflow-wrap: break-word;
    margin-right: 1rem;
}

#files-area-title {
    text-align: center;
    margin-top: 0;
}

.error-indicator {
    color: #C73E1D;
}

.clickable-text {
    border-bottom: 2px dashed var(--main-color);
    cursor: pointer;
}

@media screen and (max-width: 800px) {
    main {
        flex-flow: column nowrap;
        align-items: stretch;
    }
    
    .main-area {
        width: auto;
    }

    #files-area {
        flex: none;
    }

    #drop-area {
        flex: 1 0 auto;
        height: initial;
        position: initial;
    }
}